@@ -30,7 +30,8 @@ from colorama import Fore, Style
 
 from vantage6.common import (
     warning, error, info, debug,
-    bytes_to_base64s, check_config_writeable
+    bytes_to_base64s, check_config_writeable,
+    get_database_config
 )
 from vantage6.common.globals import (
     STRING_ENCODING,
@@ -299,11 +300,11 @@ def cli_node_start(name: str, config: str, environment: str,
 
         # check that config exists, if not a questionaire will be invoked
         if not NodeContext.config_exists(name, environment, system_folders):
-            question = (f"Configuration '{name}' using environment "
-                        "'{environment}' does not exist.\n  Do you want to "
-                        "create this config now?")
+            warning(f"Configuration {Fore.RED}{name}{Style.RESET_ALL} "
+                    f"using environment {Fore.RED}{environment}"
+                    f"{Style.RESET_ALL} does not exist. ")
 
-            if q.confirm(question).ask():
+            if q.confirm("Create this configuration now?").ask():
                 configuration_wizard("node", name, environment, system_folders)
 
             else:
@@ -438,11 +439,26 @@ def cli_node_start(name: str, config: str, environment: str,
 
     # only mount the DB if it is a file
     info("Setting up databases")
-    db_labels = ctx.databases.keys()
+
+    # Check wether the new or old database configuration is used
+    # TODO: remove this in version v4+
+    old_format = isinstance(ctx.databases, dict)
+    if old_format:
+        db_labels = ctx.databases.keys()
+        warning('Using the old database configuration format. Please update.')
+        debug('You are using the db config old format, algorithms using the '
+              'auto wrapper will not work!')
+    else:
+        db_labels = [db['label'] for db in ctx.databases]
+
     for label in db_labels:
 
-        uri = ctx.databases[label]
-        info(f"  Processing database '{label}:{uri}'")
+        db_config = get_database_config(ctx.databases, label)
+        uri = db_config['uri']
+        db_type = db_config['type']
+
+        info(f"  Processing {Fore.GREEN}{db_type}{Style.RESET_ALL} database "
+             f"{Fore.GREEN}{label}:{uri}{Style.RESET_ALL}")
         label_capitals = label.upper()
 
         try:
